--------------------------------------------------------------------------------
-- Copyright (c) 2001-2002 Rational Software Corporation. All rights reserved.--
--                                                                            --
--                Product: Rational(R) Test RealTime                          --
--                                                                            --
--      Product Component: All                                                --
--                                                                            --
--               Language: Ada                                                --
--                                                                            --
--        Product version: 2002.05.03                                         --
--                                                                            --
-- Target Deployment Port: adagnat                                            --
--                         Ada95 Gnat                                         --
--                                                                            --
--                   File: ada-characters-handling.ads                        --
--                         Ada95 package: Ada.Characters.Handling             --
--                                                                            --
-- Rational, the Rational logo are registered trademarks of                   --
-- Rational Software Corporation.                                             --
--                                                                            --
-- The placing of the copyright notices on Rational source code is not        --
-- intended to mean that they are published works, but are included in the    --
-- event of inadvertent publication. The source code of Rational contains     --
-- trade secrets and other valuable confidential information of Rational      --
-- Software Corporation. Rational Software Corporation and its licensors      --
-- retain ownership to Rational Products in both source and object code       --
-- format, and related documentation and all rights therein including         --
-- copyrights, patents and trade secrets.                                     --
--                                                                            --
--                                                                            --
-- U.S. Government Rights                                                     --
--                                                                            --
-- Use, duplication, or disclosure by the U.S. Government is subject to       --
-- restrictions set forth in the applicable Rational License Agreement        --
-- and in DFARS 227.7202-1(a) and 227.7202-3(a) (1995), DFARS                 --
-- 252.227-7013(c)(1)(ii)(Oct 1988), FAR 12.212(a) 1995, FAR 52.227-19,       --
-- or FAR 52.227-14, as applicable.                                           --
--                                                                            --
-- Unless otherwise agreed to in writing, use of Rational products is         --
-- governed by the Rational Product License Agreement provided with           --
-- the product.                                                               --
--------------------------------------------------------------------------------

--------------------------------------------------------------------------
-- $Revision: 1.2 $
-- $Descr: Ada95 package: Ada.Characters.Handling$
--------------------------------------------------------------------------
--
-- Ada95 Source Definition,
-- From LRM Ada95 A.3.4 - The Package Ada.Characters.Handling.
-- 
--------------------------------------------------------------------------

package Ada.Characters.Handling is

   pragma Preelaborate(Handling);

   --Character classification functions

   function Is_Control           (Item : in Character) return Boolean;
   function Is_Graphic           (Item : in Character) return Boolean;
   function Is_Letter            (Item : in Character) return Boolean;
   function Is_Lower             (Item : in Character) return Boolean;
   function Is_Upper             (Item : in Character) return Boolean;
   function Is_Basic             (Item : in Character) return Boolean;
   function Is_Digit             (Item : in Character) return Boolean;
   function Is_Decimal_Digit     (Item : in Character) return Boolean renames Is_Digit;
   function Is_Hexadecimal_Digit (Item : in Character) return Boolean;
   function Is_Alphanumeric      (Item : in Character) return Boolean;
   function Is_Special           (Item : in Character) return Boolean;

   --Conversion functions for Character and String

   function To_Lower (Item : in Character) return Character;
   function To_Upper (Item : in Character) return Character;
   function To_Basic (Item : in Character) return Character;

   function To_Lower (Item : in String) return String;
   function To_Upper (Item : in String) return String;
   function To_Basic (Item : in String) return String;

   --Classifications of and conversions between Character and ISO 646

   subtype ISO_646 is
           Character range Character'Val(0) .. Character'Val(127);

   function Is_ISO_646 (Item : in Character) return Boolean;
   function Is_ISO_646 (Item : in String)    return Boolean;

   function To_ISO_646 (Item       : in Character;
                        Substitute : in ISO_646 := ' ') return ISO_646;

   function To_ISO_646 (Item       : in String;
                        Substitute : in ISO_646 := ' ') return String;

   --Classifications of and conversions between Wide_Character and Character.

   function Is_Character (Item : in Wide_Character) return Boolean;
   function Is_String    (Item : in Wide_String)    return Boolean;

   function To_Character (Item       : in Wide_Character;
                          Substitute : in Character := ' ') return Character;

   function To_String    (Item       : in Wide_String;
                          Substitute : in Character := ' ') return String;

   function To_Wide_Character (Item : in Character) return Wide_Character;

   function To_Wide_String    (Item : in String)    return Wide_String;

end Ada.Characters.Handling;
-- 
--------------------------------------------------------------------------
