--------------------------------------------------------------------------------
-- Copyright (c) 2001-2002 Rational Software Corporation. All rights reserved.--
--                                                                            --
--                Product: Rational(R) Test RealTime                          --
--                                                                            --
--      Product Component: All                                                --
--                                                                            --
--               Language: Ada                                                --
--                                                                            --
--        Product version: 2002.05.03                                         --
--                                                                            --
-- Target Deployment Port: adagnat                                            --
--                         Ada95 Gnat                                         --
--                                                                            --
--                   File: ada-direct_io.ads                                  --
--                         Ada95 package: Ada.Direct_IO                       --
--                                                                            --
-- Rational, the Rational logo are registered trademarks of                   --
-- Rational Software Corporation.                                             --
--                                                                            --
-- The placing of the copyright notices on Rational source code is not        --
-- intended to mean that they are published works, but are included in the    --
-- event of inadvertent publication. The source code of Rational contains     --
-- trade secrets and other valuable confidential information of Rational      --
-- Software Corporation. Rational Software Corporation and its licensors      --
-- retain ownership to Rational Products in both source and object code       --
-- format, and related documentation and all rights therein including         --
-- copyrights, patents and trade secrets.                                     --
--                                                                            --
--                                                                            --
-- U.S. Government Rights                                                     --
--                                                                            --
-- Use, duplication, or disclosure by the U.S. Government is subject to       --
-- restrictions set forth in the applicable Rational License Agreement        --
-- and in DFARS 227.7202-1(a) and 227.7202-3(a) (1995), DFARS                 --
-- 252.227-7013(c)(1)(ii)(Oct 1988), FAR 12.212(a) 1995, FAR 52.227-19,       --
-- or FAR 52.227-14, as applicable.                                           --
--                                                                            --
-- Unless otherwise agreed to in writing, use of Rational products is         --
-- governed by the Rational Product License Agreement provided with           --
-- the product.                                                               --
--------------------------------------------------------------------------------

--------------------------------------------------------------------------
-- $Revision: 1.2 $
-- $Descr: Ada95 package: Ada.Direct_IO$
--------------------------------------------------------------------------
--
-- Ada95 Source Definition,
-- From LRM Ada95 A.8.4 - The generic package Ada.Direct_IO
-- Modified to handle Implementation Dependent Definitions
--
--------------------------------------------------------------------------
with RTRT_Imp95 ;

with Ada.IO_Exceptions;

generic
       type Element_Type is private;
package Ada.Direct_IO is

    type File_Type is limited private;

    type File_Mode is (In_File, Inout_File, Out_File);
    type Count     is range 0 .. RTRT_Imp95.c_Ada_Direct_IO_Count_Last ;
    subtype Positive_Count is Count range 1 .. Count'Last;

    -- File management

    procedure Create(File : in out File_Type;
                     Mode : in File_Mode := Inout_File;
                     Name : in String := "";
                     Form : in String := "");

    procedure Open  (File : in out File_Type;
                     Mode : in File_Mode;
                     Name : in String;
                     Form : in String := "");

    procedure Close (File : in out File_Type);
    procedure Delete(File : in out File_Type);
    procedure Reset (File : in out File_Type; Mode : in File_Mode);
    procedure Reset (File : in out File_Type);

    function Mode   (File : in File_Type) return File_Mode;
    function Name   (File : in File_Type) return String;
    function Form   (File : in File_Type) return String;

    function Is_Open(File : in File_Type) return Boolean;

    -- Input and output operations

    procedure Read (File : in File_Type; Item : out Element_Type;
                                         From : in Positive_Count);
    procedure Read (File : in File_Type; Item : out Element_Type);

    procedure Write(File : in File_Type; Item : in  Element_Type;
                                         To   : in Positive_Count);
    procedure Write(File : in File_Type; Item : in Element_Type);

    procedure Set_Index(File : in File_Type; To : in Positive_Count);

    function Index(File : in File_Type) return Positive_Count;
    function Size (File : in File_Type) return Count;

    function End_Of_File(File : in File_Type) return Boolean;

    -- Exceptions

    Status_Error : exception renames IO_Exceptions.Status_Error;
    Mode_Error   : exception renames IO_Exceptions.Mode_Error;
    Name_Error   : exception renames IO_Exceptions.Name_Error;
    Use_Error    : exception renames IO_Exceptions.Use_Error;
    Device_Error : exception renames IO_Exceptions.Device_Error;
    End_Error    : exception renames IO_Exceptions.End_Error;
    Data_Error   : exception renames IO_Exceptions.Data_Error;

private

    -- not specified by the language
    type File_Type is new RTRT_Imp95.t_Ada_Direct_IO_File_Type ;

end Ada.Direct_IO;
--
--------------------------------------------------------------------------
