--------------------------------------------------------------------------------
-- Copyright (c) 2001-2002 Rational Software Corporation. All rights reserved.--
--                                                                            --
--                Product: Rational(R) Test RealTime                          --
--                                                                            --
--      Product Component: All                                                --
--                                                                            --
--               Language: Ada                                                --
--                                                                            --
--        Product version: 2002.05.03                                         --
--                                                                            --
-- Target Deployment Port: adagnat                                            --
--                         Ada95 Gnat                                         --
--                                                                            --
--                   File: ada-real_time.ads                                  --
--                         Ada95 package: Ada.Real_Time                       --
--                                                                            --
-- Rational, the Rational logo are registered trademarks of                   --
-- Rational Software Corporation.                                             --
--                                                                            --
-- The placing of the copyright notices on Rational source code is not        --
-- intended to mean that they are published works, but are included in the    --
-- event of inadvertent publication. The source code of Rational contains     --
-- trade secrets and other valuable confidential information of Rational      --
-- Software Corporation. Rational Software Corporation and its licensors      --
-- retain ownership to Rational Products in both source and object code       --
-- format, and related documentation and all rights therein including         --
-- copyrights, patents and trade secrets.                                     --
--                                                                            --
--                                                                            --
-- U.S. Government Rights                                                     --
--                                                                            --
-- Use, duplication, or disclosure by the U.S. Government is subject to       --
-- restrictions set forth in the applicable Rational License Agreement        --
-- and in DFARS 227.7202-1(a) and 227.7202-3(a) (1995), DFARS                 --
-- 252.227-7013(c)(1)(ii)(Oct 1988), FAR 12.212(a) 1995, FAR 52.227-19,       --
-- or FAR 52.227-14, as applicable.                                           --
--                                                                            --
-- Unless otherwise agreed to in writing, use of Rational products is         --
-- governed by the Rational Product License Agreement provided with           --
-- the product.                                                               --
--------------------------------------------------------------------------------

--------------------------------------------------------------------------
-- $Revision: 1.3 $
-- $Descr: Ada95 package: Ada.Real_Time$
--------------------------------------------------------------------------
--
-- Ada95 Source Definition,
-- From LRM Ada95 D.8 - Monotonic Time
-- Modified to handle Implementation Dependent Definitions
--
--------------------------------------------------------------------------
with RTRT_Imp95 ;

package Ada.Real_Time is

    type Time is private;

    Time_First : constant Time;
    Time_Last : constant Time;
    Time_Unit : constant := RTRT_Imp95.c_Ada_Real_Time_Time_Unit ;

    -- (blank)


    type Time_Span is private;
    Time_Span_First : constant Time_Span;
    Time_Span_Last : constant Time_Span;
    Time_Span_Zero : constant Time_Span;
    Time_Span_Unit : constant Time_Span;


    Tick : constant Time_Span;
    function Clock return Time;


    function "+" (Left : Time; Right : Time_Span) return Time;
    function "+" (Left : Time_Span; Right : Time) return Time;
    function "-" (Left : Time; Right : Time_Span) return Time;
    function "-" (Left : Time; Right : Time) return Time_Span;


    function "<" (Left, Right : Time) return Boolean;
    function "<="(Left, Right : Time) return Boolean;
    function ">" (Left, Right : Time) return Boolean;
    function ">="(Left, Right : Time) return Boolean;


    function "+" (Left, Right : Time_Span) return Time_Span;
    function "-" (Left, Right : Time_Span) return Time_Span;
    function "-" (Right : Time_Span) return Time_Span;
    function "*" (Left : Time_Span; Right : Integer) return Time_Span;
    function "*" (Left : Integer; Right : Time_Span) return Time_Span;
    function "/" (Left, Right : Time_Span) return Integer;
    function "/" (Left : Time_Span; Right : Integer) return Time_Span;

    function "abs"(Right : Time_Span) return Time_Span;


    function "<" (Left, Right : Time_Span) return Boolean;
    function "<="(Left, Right : Time_Span) return Boolean;
    function ">" (Left, Right : Time_Span) return Boolean;
    function ">="(Left, Right : Time_Span) return Boolean;


    function To_Duration (TS : Time_Span) return Duration;
    function To_Time_Span (D : Duration) return Time_Span;


    function Nanoseconds  (NS : Integer) return Time_Span;
    function Microseconds (US : Integer) return Time_Span;
    function Milliseconds (MS : Integer) return Time_Span;

    type Seconds_Count is range 
                   RTRT_Imp95.t_Ada_Real_Time_Seconds_Count'first ..
                   RTRT_Imp95.t_Ada_Real_Time_Seconds_Count'last ;

    procedure Split(T : in Time; SC : out Seconds_Count; TS : out Time_Span);
    function Time_Of(SC : Seconds_Count; TS : Time_Span) return Time;

private
    -- not specified by the language

    Type Time is new RTRT_Imp95.t_Ada_Real_Time_Time ;

    Time_First : constant Time
     :=  Time(RTRT_Imp95.c_Ada_Real_Time_Time_First);
    Time_Last : constant Time
     :=  Time(RTRT_Imp95.c_Ada_Real_Time_Time_Last) ;

    type Time_Span is new RTRT_Imp95.t_Ada_Real_Time_Time_Span ;

    Time_Span_First : constant Time_Span
     := Time_Span(RTRT_Imp95.c_Ada_Real_Time_Time_Span_First);
    Time_Span_Last : constant Time_Span
     := Time_Span(RTRT_Imp95.c_Ada_Real_Time_Time_Span_Last );
    Time_Span_Zero : constant Time_Span
     := Time_Span(RTRT_Imp95.c_Ada_Real_Time_Time_Span_Zero );
    Time_Span_Unit : constant Time_Span
     := Time_Span(RTRT_Imp95.c_Ada_Real_Time_Time_Span_Unit );


    Tick : constant Time_Span;

end Ada.Real_Time;
--
--------------------------------------------------------------------------
