--------------------------------------------------------------------------------
-- Copyright (c) 2001-2002 Rational Software Corporation. All rights reserved.--
--                                                                            --
--                Product: Rational(R) Test RealTime                          --
--                                                                            --
--      Product Component: All                                                --
--                                                                            --
--               Language: Ada                                                --
--                                                                            --
--        Product version: 2002.05.03                                         --
--                                                                            --
-- Target Deployment Port: adagnat                                            --
--                         Ada95 Gnat                                         --
--                                                                            --
--                   File: ada-strings-fixed.ads                              --
--                         Ada95 package: Ada.Strings.Fixed                   --
--                                                                            --
-- Rational, the Rational logo are registered trademarks of                   --
-- Rational Software Corporation.                                             --
--                                                                            --
-- The placing of the copyright notices on Rational source code is not        --
-- intended to mean that they are published works, but are included in the    --
-- event of inadvertent publication. The source code of Rational contains     --
-- trade secrets and other valuable confidential information of Rational      --
-- Software Corporation. Rational Software Corporation and its licensors      --
-- retain ownership to Rational Products in both source and object code       --
-- format, and related documentation and all rights therein including         --
-- copyrights, patents and trade secrets.                                     --
--                                                                            --
--                                                                            --
-- U.S. Government Rights                                                     --
--                                                                            --
-- Use, duplication, or disclosure by the U.S. Government is subject to       --
-- restrictions set forth in the applicable Rational License Agreement        --
-- and in DFARS 227.7202-1(a) and 227.7202-3(a) (1995), DFARS                 --
-- 252.227-7013(c)(1)(ii)(Oct 1988), FAR 12.212(a) 1995, FAR 52.227-19,       --
-- or FAR 52.227-14, as applicable.                                           --
--                                                                            --
-- Unless otherwise agreed to in writing, use of Rational products is         --
-- governed by the Rational Product License Agreement provided with           --
-- the product.                                                               --
--------------------------------------------------------------------------------

--------------------------------------------------------------------------
-- $Revision: 1.2 $
-- $Descr: Ada95 package: Ada.Strings.Fixed$
--------------------------------------------------------------------------
--
-- Ada95 Source Definition,
-- From LRM Ada95 A.4.3 - Fixed Length String Handling
--
--------------------------------------------------------------------------
with Ada.Strings.Maps;

package Ada.Strings.Fixed is

          pragma Preelaborate(Fixed);

       -- "Copy" procedure for strings of possibly different lengths

          procedure Move (Source  : in  String;
                          Target  : out String;
                          Drop    : in  Truncation := Error;
                          Justify : in  Alignment  := Left;
                          Pad     : in  Character  := Space);

       -- Search subprograms

          function Index (Source   : in String;
                          Pattern  : in String;
                          Going    : in Direction := Forward;
                          Mapping  : in Maps.Character_Mapping
                                       := Maps.Identity)
             return Natural;

          function Index (Source   : in String;
                          Pattern  : in String;
                          Going    : in Direction := Forward;
                          Mapping  : in Maps.Character_Mapping_Function)
             return Natural;

          function Index (Source : in String;
                          Set    : in Maps.Character_Set;
                          Test   : in Membership := Inside;
                          Going  : in Direction  := Forward)
             return Natural;

          function Index_Non_Blank (Source : in String;
                                    Going  : in Direction := Forward)
             return Natural;

          function Count (Source   : in String;
                          Pattern  : in String;
                          Mapping  : in Maps.Character_Mapping
                                        := Maps.Identity)
             return Natural;

          function Count (Source   : in String;
                          Pattern  : in String;
                          Mapping  : in Maps.Character_Mapping_Function)
             return Natural;

          function Count (Source   : in String;
                          Set      : in Maps.Character_Set)
             return Natural;

          procedure Find_Token (Source : in String;
                                Set    : in Maps.Character_Set;
                                Test   : in Membership;
                                First  : out Positive;
                                Last   : out Natural);

       -- String translation subprograms

          function Translate (Source  : in String;
                              Mapping : in Maps.Character_Mapping)
             return String;

          procedure Translate (Source  : in out String;
                               Mapping : in Maps.Character_Mapping);

          function Translate (Source  : in String;
                              Mapping : in Maps.Character_Mapping_Function)
             return String;

          procedure Translate (Source  : in out String;
                               Mapping : in Maps.Character_Mapping_Function);

       -- String transformation subprograms

          function Replace_Slice (Source   : in String;
                                  Low      : in Positive;
                                  High     : in Natural;
                                  By       : in String)
             return String;

          procedure Replace_Slice (Source   : in out String;
                                   Low      : in Positive;
                                   High     : in Natural;
                                   By       : in String;
                                   Drop     : in Truncation := Error;
                                   Justify  : in Alignment  := Left;
                                   Pad      : in Character  := Space);

          function Insert (Source   : in String;
                           Before   : in Positive;
                           New_Item : in String)
             return String;

          procedure Insert (Source   : in out String;
                            Before   : in Positive;
                            New_Item : in String;
                            Drop     : in Truncation := Error);

          function Overwrite (Source   : in String;
                              Position : in Positive;
                              New_Item : in String)
             return String;

          procedure Overwrite (Source   : in out String;
                               Position : in Positive;
                               New_Item : in String;
                               Drop     : in Truncation := Right);

          function Delete (Source  : in String;
                           From    : in Positive;
                           Through : in Natural)
             return String;

          procedure Delete (Source  : in out String;
                            From    : in Positive;
                            Through : in Natural;
                            Justify : in Alignment := Left;
                            Pad     : in Character := Space);

        --String selector subprograms
          function Trim (Source : in String;
                         Side   : in Trim_End)
             return String;

          procedure Trim (Source  : in out String;
                          Side    : in Trim_End;
                          Justify : in Alignment := Left;
                          Pad     : in Character := Space);

          function Trim (Source : in String;
                         Left   : in Maps.Character_Set;
                         Right  : in Maps.Character_Set)
             return String;

          procedure Trim (Source  : in out String;
                          Left    : in Maps.Character_Set;
                          Right   : in Maps.Character_Set;
                          Justify : in Alignment := Strings.Left;
                          Pad     : in Character := Space);

          function Head (Source : in String;
                         Count  : in Natural;
                         Pad    : in Character := Space)
             return String;

          procedure Head (Source  : in out String;
                          Count   : in Natural;
                          Justify : in Alignment := Left;
                          Pad     : in Character := Space);

          function Tail (Source : in String;
                         Count  : in Natural;
                         Pad    : in Character := Space)
             return String;

          procedure Tail (Source  : in out String;
                          Count   : in Natural;
                          Justify : in Alignment := Left;
                          Pad     : in Character := Space);

       --String constructor functions

          function "*" (Left  : in Natural;
                        Right : in Character) return String;

          function "*" (Left  : in Natural;
                        Right : in String) return String;

end Ada.Strings.Fixed;
--
--------------------------------------------------------------------------
