--------------------------------------------------------------------------------
-- Copyright (c) 2001-2002 Rational Software Corporation. All rights reserved.--
--                                                                            --
--                Product: Rational(R) Test RealTime                          --
--                                                                            --
--      Product Component: All                                                --
--                                                                            --
--               Language: Ada                                                --
--                                                                            --
--        Product version: 2002.05.03                                         --
--                                                                            --
-- Target Deployment Port: adagnat                                            --
--                         Ada95 Gnat                                         --
--                                                                            --
--                   File: ada-strings-maps.ads                               --
--                         Ada95 package: Ada.Strings.Maps                    --
--                                                                            --
-- Rational, the Rational logo are registered trademarks of                   --
-- Rational Software Corporation.                                             --
--                                                                            --
-- The placing of the copyright notices on Rational source code is not        --
-- intended to mean that they are published works, but are included in the    --
-- event of inadvertent publication. The source code of Rational contains     --
-- trade secrets and other valuable confidential information of Rational      --
-- Software Corporation. Rational Software Corporation and its licensors      --
-- retain ownership to Rational Products in both source and object code       --
-- format, and related documentation and all rights therein including         --
-- copyrights, patents and trade secrets.                                     --
--                                                                            --
--                                                                            --
-- U.S. Government Rights                                                     --
--                                                                            --
-- Use, duplication, or disclosure by the U.S. Government is subject to       --
-- restrictions set forth in the applicable Rational License Agreement        --
-- and in DFARS 227.7202-1(a) and 227.7202-3(a) (1995), DFARS                 --
-- 252.227-7013(c)(1)(ii)(Oct 1988), FAR 12.212(a) 1995, FAR 52.227-19,       --
-- or FAR 52.227-14, as applicable.                                           --
--                                                                            --
-- Unless otherwise agreed to in writing, use of Rational products is         --
-- governed by the Rational Product License Agreement provided with           --
-- the product.                                                               --
--------------------------------------------------------------------------------

--------------------------------------------------------------------------
-- $Revision: 1.2 $
-- $Descr: Ada95 package: Ada.Strings.Maps$
--------------------------------------------------------------------------
--
-- Ada95 Source Definition,
-- From LRM Ada95 A.4.2 - The Package Strings.Maps
-- Modified to handle Implementation Dependent Definitions
--
--------------------------------------------------------------------------
with RTRT_Imp95 ;

package Ada.Strings.Maps is

   pragma Preelaborate(Maps);

   -- Representation for a set of character values:
   type Character_Set is private;

   Null_Set : constant Character_Set;

   type Character_Range is
            record
               Low  : Character;
               High : Character;
            end record;
          -- Represents Character range Low..High

   type Character_Ranges is array (Positive range <>) of Character_Range;

   function To_Set    (Ranges : in Character_Ranges) return Character_Set;

   function To_Set    (Span   : in Character_Range)  return Character_Set;

   function To_Ranges (Set    : in Character_Set)    return Character_Ranges;

   function "="   (Left, Right : in Character_Set) return Boolean;

   function "not" (Right : in Character_Set)       return Character_Set;
   function "and" (Left, Right : in Character_Set) return Character_Set;
   function "or"  (Left, Right : in Character_Set) return Character_Set;
   function "xor" (Left, Right : in Character_Set) return Character_Set;
   function "-"   (Left, Right : in Character_Set) return Character_Set;

   function Is_In (Element : in Character;
                   Set     : in Character_Set)
             return Boolean;

   function Is_Subset (Elements : in Character_Set;
                       Set      : in Character_Set)
             return Boolean;

   function "<=" (Left  : in Character_Set;
                  Right : in Character_Set)
             return Boolean renames Is_Subset;

   -- Alternative representation for a set of character values:
   subtype Character_Sequence is String;

   function To_Set (Sequence  : in Character_Sequence) return Character_Set;

   function To_Set (Singleton : in Character)          return Character_Set;

   function To_Sequence (Set  : in Character_Set)      return Character_Sequence;

   -- Representation for a character to character mapping:
   type Character_Mapping is private;

   function Value (Map     : in Character_Mapping;
                   Element : in Character)
             return Character;

   Identity : constant Character_Mapping;

   function To_Mapping (From, To : in Character_Sequence) return Character_Mapping;

   function To_Domain (Map : in Character_Mapping) return Character_Sequence;
   function To_Range  (Map : in Character_Mapping) return Character_Sequence;

   type Character_Mapping_Function is
             access function (From : in Character) return Character;

private

     -- not specified by the language
     Type Character_Set is 
      new RTRT_Imp95.t_Ada_Strings_Maps_Character_Set ;

     Type Character_Mapping is 
      new RTRT_Imp95.t_Ada_Strings_Maps_Character_Mapping ;

     Null_Set : constant Character_Set 
                := Character_Set(RTRT_Imp95.c_Ada_Strings_Maps_Null_Set) ;

     Identity : constant Character_Mapping 
                := Character_Mapping(RTRT_Imp95.c_Ada_Strings_Maps_Identity) ;

end Ada.Strings.Maps;
--
--------------------------------------------------------------------------
