--------------------------------------------------------------------------------
-- Copyright (c) 2001-2002 Rational Software Corporation. All rights reserved.--
--                                                                            --
--                Product: Rational(R) Test RealTime                          --
--                                                                            --
--      Product Component: All                                                --
--                                                                            --
--               Language: Ada                                                --
--                                                                            --
--        Product version: 2002.05.03                                         --
--                                                                            --
-- Target Deployment Port: adagnat                                            --
--                         Ada95 Gnat                                         --
--                                                                            --
--                   File: ada-strings-wide_bounded.ads                       --
--                         Ada95 package: Ada.Strings.Wide_Bounded            --
--                                                                            --
-- Rational, the Rational logo are registered trademarks of                   --
-- Rational Software Corporation.                                             --
--                                                                            --
-- The placing of the copyright notices on Rational source code is not        --
-- intended to mean that they are published works, but are included in the    --
-- event of inadvertent publication. The source code of Rational contains     --
-- trade secrets and other valuable confidential information of Rational      --
-- Software Corporation. Rational Software Corporation and its licensors      --
-- retain ownership to Rational Products in both source and object code       --
-- format, and related documentation and all rights therein including         --
-- copyrights, patents and trade secrets.                                     --
--                                                                            --
--                                                                            --
-- U.S. Government Rights                                                     --
--                                                                            --
-- Use, duplication, or disclosure by the U.S. Government is subject to       --
-- restrictions set forth in the applicable Rational License Agreement        --
-- and in DFARS 227.7202-1(a) and 227.7202-3(a) (1995), DFARS                 --
-- 252.227-7013(c)(1)(ii)(Oct 1988), FAR 12.212(a) 1995, FAR 52.227-19,       --
-- or FAR 52.227-14, as applicable.                                           --
--                                                                            --
-- Unless otherwise agreed to in writing, use of Rational products is         --
-- governed by the Rational Product License Agreement provided with           --
-- the product.                                                               --
--------------------------------------------------------------------------------

--------------------------------------------------------------------------
-- $Revision: 1.2 $
-- $Descr: Ada95 package: Ada.Strings.Wide_Bounded$
--------------------------------------------------------------------------
--
-- Ada95 Source Definition,
-- From LRM Ada95 A.4.7 - Wide String Handling
-- Modified to handle Implementation Dependent Definitions
--
--------------------------------------------------------------------------
with RTRT_Imp95 ;

with Ada.Strings.Wide_Maps;
package Ada.Strings.Wide_Bounded is

    pragma Preelaborate(Wide_Bounded);

    generic
             Max   : Positive;    -- Maximum length of a Bounded_Wide_String
    package Generic_Bounded_Length is

             Max_Length : constant Positive := Max;

             type Bounded_Wide_String is private;

             Null_Bounded_Wide_String : constant Bounded_Wide_String;

             subtype Length_Range is Natural range 0 .. Max_Length;

             function Length (Source : in Bounded_Wide_String) return Length_Range;

          -- Conversion, Concatenation, and Selection functions

             function To_Bounded_Wide_String (Source : in Wide_String;
                                         Drop   : in Truncation := Error)
                return Bounded_Wide_String;

             function To_Wide_String (Source : in Bounded_Wide_String) return Wide_String;

             function Append (Left, Right : in Bounded_Wide_String;
                              Drop        : in Truncation  := Error)
                return Bounded_Wide_String;

             function Append (Left  : in Bounded_Wide_String;
                              Right : in Wide_String;
                              Drop  : in Truncation := Error)
                return Bounded_Wide_String;

             function Append (Left  : in Wide_String;
                              Right : in Bounded_Wide_String;
                              Drop  : in Truncation := Error)
                return Bounded_Wide_String;

             function Append (Left  : in Bounded_Wide_String;
                              Right : in Wide_Character;
                              Drop  : in Truncation := Error)
                return Bounded_Wide_String;

             function Append (Left  : in Wide_Character;
                              Right : in Bounded_Wide_String;
                              Drop  : in Truncation := Error)
                return Bounded_Wide_String;

             procedure Append (Source   : in out Bounded_Wide_String;
                               New_Item : in Bounded_Wide_String;
                               Drop     : in Truncation  := Error);

             procedure Append (Source   : in out Bounded_Wide_String;
                               New_Item : in Wide_String;
                               Drop     : in Truncation  := Error);

             procedure Append (Source   : in out Bounded_Wide_String;
                               New_Item : in Wide_Character;
                               Drop     : in Truncation  := Error);

             function "&" (Left, Right : in Bounded_Wide_String)
                return Bounded_Wide_String;

             function "&" (Left : in Bounded_Wide_String; Right : in Wide_String)
                return Bounded_Wide_String;

             function "&" (Left : in Wide_String; Right : in Bounded_Wide_String)
                return Bounded_Wide_String;

             function "&" (Left : in Bounded_Wide_String; Right : in Wide_Character)
                return Bounded_Wide_String;

             function "&" (Left : in Wide_Character; Right : in Bounded_Wide_String)
                return Bounded_Wide_String;

             function Element (Source : in Bounded_Wide_String;
                               Index  : in Positive)
                return Wide_Character;

             procedure Replace_Element (Source : in out Bounded_Wide_String;
                                        Index  : in Positive;
                                        By     : in Wide_Character);

             function Slice (Source : in Bounded_Wide_String;
                             Low    : in Positive;
                             High   : in Natural)
                return Wide_String;

             function "="  (Left, Right : in Bounded_Wide_String) return Boolean;
             function "="  (Left : in Bounded_Wide_String; Right : in Wide_String)
               return Boolean;

             function "="  (Left : in Wide_String; Right : in Bounded_Wide_String)
               return Boolean;

             function "<"  (Left, Right : in Bounded_Wide_String) return Boolean;

             function "<"  (Left : in Bounded_Wide_String; Right : in Wide_String)
               return Boolean;

             function "<"  (Left : in Wide_String; Right : in Bounded_Wide_String)
               return Boolean;

             function "<=" (Left, Right : in Bounded_Wide_String) return Boolean;

             function "<="  (Left : in Bounded_Wide_String; Right : in Wide_String)
               return Boolean;

             function "<="  (Left : in Wide_String; Right : in Bounded_Wide_String)
               return Boolean;

             function ">"  (Left, Right : in Bounded_Wide_String) return Boolean;

             function ">"  (Left : in Bounded_Wide_String; Right : in Wide_String)
               return Boolean;

             function ">"  (Left : in Wide_String; Right : in Bounded_Wide_String)
               return Boolean;

             function ">=" (Left, Right : in Bounded_Wide_String) return Boolean;

             function ">="  (Left : in Bounded_Wide_String; Right : in Wide_String)
               return Boolean;

             function ">="  (Left : in Wide_String; Right : in Bounded_Wide_String)
               return Boolean;

          -- Search functions

             function Index (Source   : in Bounded_Wide_String;
                             Pattern  : in Wide_String;
                             Going    : in Direction := Forward;
                             Mapping  : in Wide_Maps.Wide_Character_Mapping
                                        := Wide_Maps.Identity)
                return Natural;

             function Index (Source   : in Bounded_Wide_String;
                             Pattern  : in Wide_String;
                             Going    : in Direction := Forward;
                             Mapping  : in Wide_Maps.Wide_Character_Mapping_Function)
                return Natural;

             function Index (Source : in Bounded_Wide_String;
                             Set    : in Wide_Maps.Wide_Character_Set;
                             Test   : in Membership := Inside;
                             Going  : in Direction  := Forward)
                return Natural;

             function Index_Non_Blank (Source : in Bounded_Wide_String;
                                       Going  : in Direction := Forward)
                return Natural;

             function Count (Source   : in Bounded_Wide_String;
                             Pattern  : in Wide_String;
                             Mapping  : in Wide_Maps.Wide_Character_Mapping
                                          := Wide_Maps.Identity)
                return Natural;

             function Count (Source   : in Bounded_Wide_String;
                             Pattern  : in Wide_String;
                             Mapping  : in Wide_Maps.Wide_Character_Mapping_Function)
                return Natural;

             function Count (Source   : in Bounded_Wide_String;
                             Set      : in Wide_Maps.Wide_Character_Set)
                return Natural;

             procedure Find_Token (Source : in Bounded_Wide_String;
                                   Set    : in Wide_Maps.Wide_Character_Set;
                                   Test   : in Membership;
                                   First  : out Positive;
                                   Last   : out Natural);

          -- Wide_String translation subprograms

             function Translate (Source  : in Bounded_Wide_String;
                                 Mapping : in Wide_Maps.Wide_Character_Mapping)
                return Bounded_Wide_String;

             procedure Translate (Source  : in out Bounded_Wide_String;
                                  Mapping : in Wide_Maps.Wide_Character_Mapping);

             function Translate (Source  : in Bounded_Wide_String;
                                 Mapping : in Wide_Maps.Wide_Character_Mapping_Function)
                return Bounded_Wide_String;

             procedure Translate (Source  : in out Bounded_Wide_String;
                                  Mapping : in Wide_Maps.Wide_Character_Mapping_Function);

          -- Wide_String transformation subprograms

             function Replace_Slice (Source   : in Bounded_Wide_String;
                                     Low      : in Positive;
                                     High     : in Natural;
                                     By       : in Wide_String;
                                     Drop     : in Truncation := Error)
                return Bounded_Wide_String;

             procedure Replace_Slice (Source   : in out Bounded_Wide_String;
                                      Low      : in Positive;
                                      High     : in Natural;
                                      By       : in Wide_String;
                                      Drop     : in Truncation := Error);

             function Insert (Source   : in Bounded_Wide_String;
                              Before   : in Positive;
                              New_Item : in Wide_String;
                              Drop     : in Truncation := Error)
                return Bounded_Wide_String;

             procedure Insert (Source   : in out Bounded_Wide_String;
                               Before   : in Positive;
                               New_Item : in Wide_String;
                               Drop     : in Truncation := Error);

             function Overwrite (Source    : in Bounded_Wide_String;
                                 Position  : in Positive;
                                 New_Item  : in Wide_String;
                                 Drop      : in Truncation := Error)
                return Bounded_Wide_String;

             procedure Overwrite (Source    : in out Bounded_Wide_String;
                                  Position  : in Positive;
                                  New_Item  : in Wide_String;
                                  Drop      : in Truncation := Error);

             function Delete (Source  : in Bounded_Wide_String;
                              From    : in Positive;
                              Through : in Natural)
                return Bounded_Wide_String;

             procedure Delete (Source  : in out Bounded_Wide_String;
                               From    : in Positive;
                               Through : in Natural);

       --Wide_String selector subprograms

             function Trim (Source : in Bounded_Wide_String;
                            Side   : in Trim_End)
                return Bounded_Wide_String;
             procedure Trim (Source : in out Bounded_Wide_String;
                             Side   : in Trim_End);

             function Trim (Source : in Bounded_Wide_String;
                            Left   : in Wide_Maps.Wide_Character_Set;
                            Right  : in Wide_Maps.Wide_Character_Set)
                return Bounded_Wide_String;

             procedure Trim (Source : in out Bounded_Wide_String;
                             Left   : in Wide_Maps.Wide_Character_Set;
                             Right  : in Wide_Maps.Wide_Character_Set);

             function Head (Source : in Bounded_Wide_String;
                            Count  : in Natural;
                            Pad    : in Wide_Character  := Wide_Space;
                            Drop   : in Truncation := Error)
                return Bounded_Wide_String;

             procedure Head (Source : in out Bounded_Wide_String;
                             Count  : in Natural;
                             Pad    : in Wide_Character  := Wide_Space;
                             Drop   : in Truncation := Error);

             function Tail (Source : in Bounded_Wide_String;
                            Count  : in Natural;
                            Pad    : in Wide_Character  := Wide_Space;
                            Drop   : in Truncation := Error)
                return Bounded_Wide_String;

             procedure Tail (Source : in out Bounded_Wide_String;
                             Count  : in Natural;
                             Pad    : in Wide_Character  := Wide_Space;
                             Drop   : in Truncation := Error);

       --Wide_String constructor subprograms

             function "*" (Left  : in Natural;
                           Right : in Wide_Character)
                return Bounded_Wide_String;

             function "*" (Left  : in Natural;
                           Right : in Wide_String)
                return Bounded_Wide_String;

             function "*" (Left  : in Natural;
                           Right : in Bounded_Wide_String)
                return Bounded_Wide_String;

             function Replicate (Count : in Natural;
                                 Item  : in Wide_Character;
                                 Drop  : in Truncation := Error)
                return Bounded_Wide_String;

             function Replicate (Count : in Natural;
                                 Item  : in Wide_String;
                                 Drop  : in Truncation := Error)
                return Bounded_Wide_String;

             function Replicate (Count : in Natural;
                                 Item  : in Bounded_Wide_String;
                                 Drop  : in Truncation := Error)
                return Bounded_Wide_String;

   private

      -- not specified by the language
      Type Bounded_Wide_String is
        new RTRT_Imp95.t_Ada_Strings_Wide_Bounded_Bounded_Wide_String ; 

      Null_Bounded_Wide_String : constant Bounded_Wide_String
       := Bounded_Wide_String(RTRT_Imp95.c_Ada_Strings_Wide_Bounded_Null_Bounded_Wide_String) ;


   end Generic_Bounded_Length;

end Ada.Strings.Wide_Bounded;
--
--------------------------------------------------------------------------
