--------------------------------------------------------------------------------
-- Copyright (c) 2001-2002 Rational Software Corporation. All rights reserved.--
--                                                                            --
--                Product: Rational(R) Test RealTime                          --
--                                                                            --
--      Product Component: All                                                --
--                                                                            --
--               Language: Ada                                                --
--                                                                            --
--        Product version: 2002.05.03                                         --
--                                                                            --
-- Target Deployment Port: adagnat                                            --
--                         Ada95 Gnat                                         --
--                                                                            --
--                   File: ada-strings-wide_fixed.ads                         --
--                         Ada95 package: Ada.Strings.Wide_Fixed              --
--                                                                            --
-- Rational, the Rational logo are registered trademarks of                   --
-- Rational Software Corporation.                                             --
--                                                                            --
-- The placing of the copyright notices on Rational source code is not        --
-- intended to mean that they are published works, but are included in the    --
-- event of inadvertent publication. The source code of Rational contains     --
-- trade secrets and other valuable confidential information of Rational      --
-- Software Corporation. Rational Software Corporation and its licensors      --
-- retain ownership to Rational Products in both source and object code       --
-- format, and related documentation and all rights therein including         --
-- copyrights, patents and trade secrets.                                     --
--                                                                            --
--                                                                            --
-- U.S. Government Rights                                                     --
--                                                                            --
-- Use, duplication, or disclosure by the U.S. Government is subject to       --
-- restrictions set forth in the applicable Rational License Agreement        --
-- and in DFARS 227.7202-1(a) and 227.7202-3(a) (1995), DFARS                 --
-- 252.227-7013(c)(1)(ii)(Oct 1988), FAR 12.212(a) 1995, FAR 52.227-19,       --
-- or FAR 52.227-14, as applicable.                                           --
--                                                                            --
-- Unless otherwise agreed to in writing, use of Rational products is         --
-- governed by the Rational Product License Agreement provided with           --
-- the product.                                                               --
--------------------------------------------------------------------------------

--------------------------------------------------------------------------
-- $Revision: 1.2 $
-- $Descr: Ada95 package: Ada.Strings.Wide_Fixed$
--------------------------------------------------------------------------
--
-- Ada95 Source Definition,
-- From LRM Ada95 A.4.7 - Wide String Handling 
--
--------------------------------------------------------------------------
with Ada.Strings.Wide_Maps;

package Ada.Strings.Wide_Fixed is

          pragma Preelaborate(Wide_Fixed);

       -- "Copy" procedure for strings of possibly different lengths

          procedure Move (Source  : in  Wide_String;
                          Target  : out Wide_String;
                          Drop    : in  Truncation := Error;
                          Justify : in  Alignment  := Left;
                          Pad     : in  Wide_Character  := Wide_Space);

       -- Search subprograms

          function Index (Source   : in Wide_String;
                          Pattern  : in Wide_String;
                          Going    : in Direction := Forward;
                          Mapping  : in Wide_Maps.Wide_Character_Mapping
                                       := Wide_Maps.Identity)
             return Natural;

          function Index (Source   : in Wide_String;
                          Pattern  : in Wide_String;
                          Going    : in Direction := Forward;
                          Mapping  : in Wide_Maps.Wide_Character_Mapping_Function)
             return Natural;

          function Index (Source : in Wide_String;
                          Set    : in Wide_Maps.Wide_Character_Set;
                          Test   : in Membership := Inside;
                          Going  : in Direction  := Forward)
             return Natural;

          function Index_Non_Blank (Source : in Wide_String;
                                    Going  : in Direction := Forward)
             return Natural;

          function Count (Source   : in Wide_String;
                          Pattern  : in Wide_String;
                          Mapping  : in Wide_Maps.Wide_Character_Mapping
                                        := Wide_Maps.Identity)
             return Natural;

          function Count (Source   : in Wide_String;
                          Pattern  : in Wide_String;
                          Mapping  : in Wide_Maps.Wide_Character_Mapping_Function)
             return Natural;

          function Count (Source   : in Wide_String;
                          Set      : in Wide_Maps.Wide_Character_Set)
             return Natural;

          procedure Find_Token (Source : in Wide_String;
                                Set    : in Wide_Maps.Wide_Character_Set;
                                Test   : in Membership;
                                First  : out Positive;
                                Last   : out Natural);

       -- Wide_String translation subprograms

          function Translate (Source  : in Wide_String;
                              Mapping : in Wide_Maps.Wide_Character_Mapping)
             return Wide_String;

          procedure Translate (Source  : in out Wide_String;
                               Mapping : in Wide_Maps.Wide_Character_Mapping);

          function Translate (Source  : in Wide_String;
                              Mapping : in Wide_Maps.Wide_Character_Mapping_Function)
             return Wide_String;

          procedure Translate (Source  : in out Wide_String;
                               Mapping : in Wide_Maps.Wide_Character_Mapping_Function);

       -- Wide_String transformation subprograms

          function Replace_Slice (Source   : in Wide_String;
                                  Low      : in Positive;
                                  High     : in Natural;
                                  By       : in Wide_String)
             return Wide_String;

          procedure Replace_Slice (Source   : in out Wide_String;
                                   Low      : in Positive;
                                   High     : in Natural;
                                   By       : in Wide_String;
                                   Drop     : in Truncation := Error;
                                   Justify  : in Alignment  := Left;
                                   Pad      : in Wide_Character  := Wide_Space);

          function Insert (Source   : in Wide_String;
                           Before   : in Positive;
                           New_Item : in Wide_String)
             return Wide_String;

          procedure Insert (Source   : in out Wide_String;
                            Before   : in Positive;
                            New_Item : in Wide_String;
                            Drop     : in Truncation := Error);

          function Overwrite (Source   : in Wide_String;
                              Position : in Positive;
                              New_Item : in Wide_String)
             return Wide_String;

          procedure Overwrite (Source   : in out Wide_String;
                               Position : in Positive;
                               New_Item : in Wide_String;
                               Drop     : in Truncation := Right);

          function Delete (Source  : in Wide_String;
                           From    : in Positive;
                           Through : in Natural)
             return Wide_String;

          procedure Delete (Source  : in out Wide_String;
                            From    : in Positive;
                            Through : in Natural;
                            Justify : in Alignment := Left;
                            Pad     : in Wide_Character := Wide_Space);

        --Wide_String selector subprograms
          function Trim (Source : in Wide_String;
                         Side   : in Trim_End)
             return Wide_String;

          procedure Trim (Source  : in out Wide_String;
                          Side    : in Trim_End;
                          Justify : in Alignment := Left;
                          Pad     : in Wide_Character := Wide_Space);

          function Trim (Source : in Wide_String;
                         Left   : in Wide_Maps.Wide_Character_Set;
                         Right  : in Wide_Maps.Wide_Character_Set)
             return Wide_String;

          procedure Trim (Source  : in out Wide_String;
                          Left    : in Wide_Maps.Wide_Character_Set;
                          Right   : in Wide_Maps.Wide_Character_Set;
                          Justify : in Alignment := Strings.Left;
                          Pad     : in Wide_Character := Wide_Space);

          function Head (Source : in Wide_String;
                         Count  : in Natural;
                         Pad    : in Wide_Character := Wide_Space)
             return Wide_String;

          procedure Head (Source  : in out Wide_String;
                          Count   : in Natural;
                          Justify : in Alignment := Left;
                          Pad     : in Wide_Character := Wide_Space);

          function Tail (Source : in Wide_String;
                         Count  : in Natural;
                         Pad    : in Wide_Character := Wide_Space)
             return Wide_String;

          procedure Tail (Source  : in out Wide_String;
                          Count   : in Natural;
                          Justify : in Alignment := Left;
                          Pad     : in Wide_Character := Wide_Space);

       --Wide_String constructor functions

          function "*" (Left  : in Natural;
                        Right : in Wide_Character) return Wide_String;

          function "*" (Left  : in Natural;
                        Right : in Wide_String) return Wide_String;

end Ada.Strings.Wide_Fixed;
--
--------------------------------------------------------------------------
