--------------------------------------------------------------------------------
-- Copyright (c) 2001-2002 Rational Software Corporation. All rights reserved.--
--                                                                            --
--                Product: Rational(R) Test RealTime                          --
--                                                                            --
--      Product Component: All                                                --
--                                                                            --
--               Language: Ada                                                --
--                                                                            --
--        Product version: 2002.05.03                                         --
--                                                                            --
-- Target Deployment Port: adagnat                                            --
--                         Ada95 Gnat                                         --
--                                                                            --
--                   File: ada-strings-wide_maps.ads                          --
--                         Ada95 package: Ada.Strings.Wide_Maps               --
--                                                                            --
-- Rational, the Rational logo are registered trademarks of                   --
-- Rational Software Corporation.                                             --
--                                                                            --
-- The placing of the copyright notices on Rational source code is not        --
-- intended to mean that they are published works, but are included in the    --
-- event of inadvertent publication. The source code of Rational contains     --
-- trade secrets and other valuable confidential information of Rational      --
-- Software Corporation. Rational Software Corporation and its licensors      --
-- retain ownership to Rational Products in both source and object code       --
-- format, and related documentation and all rights therein including         --
-- copyrights, patents and trade secrets.                                     --
--                                                                            --
--                                                                            --
-- U.S. Government Rights                                                     --
--                                                                            --
-- Use, duplication, or disclosure by the U.S. Government is subject to       --
-- restrictions set forth in the applicable Rational License Agreement        --
-- and in DFARS 227.7202-1(a) and 227.7202-3(a) (1995), DFARS                 --
-- 252.227-7013(c)(1)(ii)(Oct 1988), FAR 12.212(a) 1995, FAR 52.227-19,       --
-- or FAR 52.227-14, as applicable.                                           --
--                                                                            --
-- Unless otherwise agreed to in writing, use of Rational products is         --
-- governed by the Rational Product License Agreement provided with           --
-- the product.                                                               --
--------------------------------------------------------------------------------

--------------------------------------------------------------------------
-- $Revision: 1.2 $
-- $Descr: Ada95 package: Ada.Strings.Wide_Maps$
--------------------------------------------------------------------------
--
-- Ada95 Source Definition,
-- From LRM Ada95 A.7 - Wide String Handling
-- Modified to handle Implementation Dependent Definitions
--
--------------------------------------------------------------------------
with RTRT_Imp95 ;
package Ada.Strings.Wide_Maps is

    pragma Preelaborate(Wide_Maps);

          -- Representation for a set of Wide_Character values:
          type Wide_Character_Set is private;

          Null_Set : constant Wide_Character_Set;

          type Wide_Character_Range is
            record
                Low  : Wide_Character;
                High : Wide_Character;
            end record;
          -- Represents Wide_Character range Low..High

          type Wide_Character_Ranges is array (Positive range <>) of Wide_Character_Range;

          function To_Set    (Ranges : in Wide_Character_Ranges) return Wide_Character_Set;

          function To_Set    (Span   : in Wide_Character_Range)  return Wide_Character_Set;

          function To_Ranges (Set    : in Wide_Character_Set)    return Wide_Character_Ranges;

          function "="   (Left, Right : in Wide_Character_Set) return Boolean;

          function "not" (Right : in Wide_Character_Set)       return Wide_Character_Set;
          function "and" (Left, Right : in Wide_Character_Set) return Wide_Character_Set;
          function "or"  (Left, Right : in Wide_Character_Set) return Wide_Character_Set;
          function "xor" (Left, Right : in Wide_Character_Set) return Wide_Character_Set;
          function "-"   (Left, Right : in Wide_Character_Set) return Wide_Character_Set;

          function Is_In (Element : in Wide_Character;
                          Set     : in Wide_Character_Set)
             return Boolean;

          function Is_Subset (Elements : in Wide_Character_Set;
                              Set      : in Wide_Character_Set)
             return Boolean;

          function "<=" (Left  : in Wide_Character_Set;
                         Right : in Wide_Character_Set)
             return Boolean renames Is_Subset;

          -- Alternative representation for a set of Wide_Character values:
          subtype Wide_Character_Sequence is Wide_String;

          function To_Set (Sequence  : in Wide_Character_Sequence) return Wide_Character_Set;

          function To_Set (Singleton : in Wide_Character) return Wide_Character_Set;

          function To_Sequence (Set  : in Wide_Character_Set) return Wide_Character_Sequence;

          -- Representation for a Wide_Character to Wide_Character mapping:
          type Wide_Character_Mapping is private;

          function Value (Map     : in Wide_Character_Mapping;
                          Element : in Wide_Character)
             return Wide_Character;

          Identity : constant Wide_Character_Mapping;

          function To_Mapping (From, To : in Wide_Character_Sequence)
             return Wide_Character_Mapping;

          function To_Domain (Map : in Wide_Character_Mapping)
             return Wide_Character_Sequence;

          function To_Range  (Map : in Wide_Character_Mapping)
             return Wide_Character_Sequence;

          type Wide_Character_Mapping_Function is
             access function (From : in Wide_Character) return Wide_Character;

private

   -- not specified by the language
   Type Wide_Character_Set is
          new RTRT_Imp95.t_Ada_Strings_Wide_Maps_Wide_Character_Set ; 

   Null_Set : constant Wide_Character_Set
                    := Wide_Character_Set(
     RTRT_Imp95.c_Ada_Strings_Wide_Maps_Null_Set) ;

   Type Wide_Character_Mapping is 
          new RTRT_Imp95.t_Ada_Strings_Wide_Maps_Wide_Character_Mapping ;

   Identity : constant Wide_Character_Mapping
                    := Wide_Character_Mapping(
     RTRT_Imp95.c_Ada_Strings_Wide_Maps_Identity) ;

End Ada.Strings.Wide_Maps;
--
--------------------------------------------------------------------------
