--------------------------------------------------------------------------------
-- Copyright (c) 2001-2002 Rational Software Corporation. All rights reserved.--
--                                                                            --
--                Product: Rational(R) Test RealTime                          --
--                                                                            --
--      Product Component: All                                                --
--                                                                            --
--               Language: Ada                                                --
--                                                                            --
--        Product version: 2002.05.03                                         --
--                                                                            --
-- Target Deployment Port: adagnat                                            --
--                         Ada95 Gnat                                         --
--                                                                            --
--                   File: ada-strings-wide_unbounded.ads                     --
--                         Ada95 package: Ada.Strings.Wide_Unbounded          --
--                                                                            --
-- Rational, the Rational logo are registered trademarks of                   --
-- Rational Software Corporation.                                             --
--                                                                            --
-- The placing of the copyright notices on Rational source code is not        --
-- intended to mean that they are published works, but are included in the    --
-- event of inadvertent publication. The source code of Rational contains     --
-- trade secrets and other valuable confidential information of Rational      --
-- Software Corporation. Rational Software Corporation and its licensors      --
-- retain ownership to Rational Products in both source and object code       --
-- format, and related documentation and all rights therein including         --
-- copyrights, patents and trade secrets.                                     --
--                                                                            --
--                                                                            --
-- U.S. Government Rights                                                     --
--                                                                            --
-- Use, duplication, or disclosure by the U.S. Government is subject to       --
-- restrictions set forth in the applicable Rational License Agreement        --
-- and in DFARS 227.7202-1(a) and 227.7202-3(a) (1995), DFARS                 --
-- 252.227-7013(c)(1)(ii)(Oct 1988), FAR 12.212(a) 1995, FAR 52.227-19,       --
-- or FAR 52.227-14, as applicable.                                           --
--                                                                            --
-- Unless otherwise agreed to in writing, use of Rational products is         --
-- governed by the Rational Product License Agreement provided with           --
-- the product.                                                               --
--------------------------------------------------------------------------------

--------------------------------------------------------------------------
-- $Revision: 1.2 $
-- $Descr: Ada95 package: Ada.Strings.Wide_Unbounded$
--------------------------------------------------------------------------
--
-- Ada95 Source Definition,
-- From LRM Ada95 A.7 - Wide String Handling
-- Modified to handle Implementation Dependent Definitions
--
--------------------------------------------------------------------------
with RTRT_Imp95 ;

with Ada.Strings.Wide_Maps;
package Ada.Strings.Wide_Unbounded is

          pragma Preelaborate(Wide_Unbounded);

          type Unbounded_Wide_String is private;

          Null_Unbounded_Wide_String : constant Unbounded_Wide_String;

          function Length (Source : in Unbounded_Wide_String) return Natural;

          type Wide_String_Access is access all Wide_String;
          procedure Free (X : in out Wide_String_Access);

       -- Conversion, Concatenation, and Selection functions

          function To_Unbounded_Wide_String (Source : in Wide_String)
             return Unbounded_Wide_String;

          function To_Unbounded_Wide_String (Length : in Natural)
             return Unbounded_Wide_String;

          function To_Wide_String (Source : in Unbounded_Wide_String) return Wide_String;

          procedure Append (Source   : in out Unbounded_Wide_String;
                            New_Item : in Unbounded_Wide_String);

          procedure Append (Source   : in out Unbounded_Wide_String;
                            New_Item : in Wide_String);

          procedure Append (Source   : in out Unbounded_Wide_String;
                            New_Item : in Wide_Character);

          function "&" (Left, Right : in Unbounded_Wide_String)
             return Unbounded_Wide_String;

          function "&" (Left : in Unbounded_Wide_String; Right : in Wide_String)
             return Unbounded_Wide_String;

          function "&" (Left : in Wide_String; Right : in Unbounded_Wide_String)
             return Unbounded_Wide_String;

          function "&" (Left : in Unbounded_Wide_String; Right : in Wide_Character)
             return Unbounded_Wide_String;

          function "&" (Left : in Wide_Character; Right : in Unbounded_Wide_String)
             return Unbounded_Wide_String;

          function Element (Source : in Unbounded_Wide_String;
                            Index  : in Positive)
             return Wide_Character;

          procedure Replace_Element (Source : in out Unbounded_Wide_String;
                                     Index  : in Positive;
                                     By     : in Wide_Character);

          function Slice (Source : in Unbounded_Wide_String;
                          Low    : in Positive;
                          High   : in Natural)
             return Wide_String;

          function "="  (Left, Right : in Unbounded_Wide_String) return Boolean;

          function "="  (Left : in Unbounded_Wide_String; Right : in Wide_String)
            return Boolean;

          function "="  (Left : in Wide_String; Right : in Unbounded_Wide_String)
            return Boolean;

          function "<"  (Left, Right : in Unbounded_Wide_String) return Boolean;

          function "<"  (Left : in Unbounded_Wide_String; Right : in Wide_String)
            return Boolean;

          function "<"  (Left : in Wide_String; Right : in Unbounded_Wide_String)
            return Boolean;

          function "<=" (Left, Right : in Unbounded_Wide_String) return Boolean;

          function "<="  (Left : in Unbounded_Wide_String; Right : in Wide_String)
            return Boolean;

          function "<="  (Left : in Wide_String; Right : in Unbounded_Wide_String)
            return Boolean;

          function ">"  (Left, Right : in Unbounded_Wide_String) return Boolean;

          function ">"  (Left : in Unbounded_Wide_String; Right : in Wide_String)
            return Boolean;

          function ">"  (Left : in Wide_String; Right : in Unbounded_Wide_String)
            return Boolean;

          function ">=" (Left, Right : in Unbounded_Wide_String) return Boolean;

          function ">="  (Left : in Unbounded_Wide_String; Right : in Wide_String)
            return Boolean;

          function ">="  (Left : in Wide_String; Right : in Unbounded_Wide_String)
            return Boolean;

       -- Search subprograms

          function Index (Source   : in Unbounded_Wide_String;
                          Pattern  : in Wide_String;
                          Going    : in Direction := Forward;
                          Mapping  : in Wide_Maps.Wide_Character_Mapping
                                       := Wide_Maps.Identity)
             return Natural;

          function Index (Source   : in Unbounded_Wide_String;
                          Pattern  : in Wide_String;
                          Going    : in Direction := Forward;
                          Mapping  : in Wide_Maps.Wide_Character_Mapping_Function)
             return Natural;

          function Index (Source : in Unbounded_Wide_String;
                          Set    : in Wide_Maps.Wide_Character_Set;
                          Test   : in Membership := Inside;
                          Going  : in Direction  := Forward) return Natural;

          function Index_Non_Blank (Source : in Unbounded_Wide_String;
                                    Going  : in Direction := Forward)
             return Natural;

          function Count (Source   : in Unbounded_Wide_String;
                          Pattern  : in Wide_String;
                          Mapping  : in Wide_Maps.Wide_Character_Mapping
                                       := Wide_Maps.Identity)
             return Natural;

          function Count (Source   : in Unbounded_Wide_String;
                          Pattern  : in Wide_String;
                          Mapping  : in Wide_Maps.Wide_Character_Mapping_Function)
             return Natural;

          function Count (Source   : in Unbounded_Wide_String;
                          Set      : in Wide_Maps.Wide_Character_Set)
             return Natural;

          procedure Find_Token (Source : in Unbounded_Wide_String;
                                Set    : in Wide_Maps.Wide_Character_Set;
                                Test   : in Membership;
                                First  : out Positive;
                                Last   : out Natural);

       -- Wide_String translation subprograms

          function Translate (Source  : in Unbounded_Wide_String;
                              Mapping : in Wide_Maps.Wide_Character_Mapping)
             return Unbounded_Wide_String;

          procedure Translate (Source  : in out Unbounded_Wide_String;
                               Mapping : in Wide_Maps.Wide_Character_Mapping);

          function Translate (Source  : in Unbounded_Wide_String;
                              Mapping : in Wide_Maps.Wide_Character_Mapping_Function)
             return Unbounded_Wide_String;

          procedure Translate (Source  : in out Unbounded_Wide_String;
                               Mapping : in Wide_Maps.Wide_Character_Mapping_Function);

       -- Wide_String transformation subprograms

          function Replace_Slice (Source   : in Unbounded_Wide_String;
                                  Low      : in Positive;
                                  High     : in Natural;
                                  By       : in Wide_String)
             return Unbounded_Wide_String;

          procedure Replace_Slice (Source   : in out Unbounded_Wide_String;
                                   Low      : in Positive;
                                   High     : in Natural;
                                   By       : in Wide_String);

          function Insert (Source   : in Unbounded_Wide_String;
                           Before   : in Positive;
                           New_Item : in Wide_String)
             return Unbounded_Wide_String;

          procedure Insert (Source   : in out Unbounded_Wide_String;
                            Before   : in Positive;
                            New_Item : in Wide_String);

          function Overwrite (Source    : in Unbounded_Wide_String;
                              Position  : in Positive;
                              New_Item  : in Wide_String)
             return Unbounded_Wide_String;

          procedure Overwrite (Source    : in out Unbounded_Wide_String;
                               Position  : in Positive;
                               New_Item  : in Wide_String);

          function Delete (Source  : in Unbounded_Wide_String;
                           From    : in Positive;
                           Through : in Natural)
             return Unbounded_Wide_String;

          procedure Delete (Source  : in out Unbounded_Wide_String;
                            From    : in Positive;
                            Through : in Natural);

          function Trim (Source : in Unbounded_Wide_String;
                         Side   : in Trim_End)
             return Unbounded_Wide_String;

          procedure Trim (Source : in out Unbounded_Wide_String;
                          Side   : in Trim_End);

          function Trim (Source : in Unbounded_Wide_String;
                         Left   : in Wide_Maps.Wide_Character_Set;
                         Right  : in Wide_Maps.Wide_Character_Set)
             return Unbounded_Wide_String;

          procedure Trim (Source : in out Unbounded_Wide_String;
                          Left   : in Wide_Maps.Wide_Character_Set;
                          Right  : in Wide_Maps.Wide_Character_Set);

          function Head (Source : in Unbounded_Wide_String;
                         Count  : in Natural;
                         Pad    : in Wide_Character := Wide_Space)
             return Unbounded_Wide_String;

          procedure Head (Source : in out Unbounded_Wide_String;
                          Count  : in Natural;
                          Pad    : in Wide_Character := Wide_Space);

          function Tail (Source : in Unbounded_Wide_String;
                         Count  : in Natural;
                         Pad    : in Wide_Character := Wide_Space)
             return Unbounded_Wide_String;

          procedure Tail (Source : in out Unbounded_Wide_String;
                          Count  : in Natural;
                          Pad    : in Wide_Character := Wide_Space);

          function "*" (Left  : in Natural;
                        Right : in Wide_Character)
             return Unbounded_Wide_String;

          function "*" (Left  : in Natural;
                        Right : in Wide_String)
             return Unbounded_Wide_String;

          function "*" (Left  : in Natural;
                        Right : in Unbounded_Wide_String)
             return Unbounded_Wide_String;

private

     -- not specified by the language
     Type Unbounded_Wide_String is 
        new RTRT_Imp95.t_Ada_Strings_Wide_Unbounded_Unbounded_Wide_String ;

     Null_Unbounded_Wide_String : constant Unbounded_Wide_String
        := Unbounded_Wide_String(RTRT_Imp95.c_Ada_Strings_Wide_Unbounded_Null_Unbounded_Wide_String) ;

end Ada.Strings.Wide_Unbounded;
--
--------------------------------------------------------------------------
