--------------------------------------------------------------------------------
-- Copyright (c) 2001-2002 Rational Software Corporation. All rights reserved.--
--                                                                            --
--                Product: Rational(R) Test RealTime                          --
--                                                                            --
--      Product Component: All                                                --
--                                                                            --
--               Language: Ada                                                --
--                                                                            --
--        Product version: 2002.05.03                                         --
--                                                                            --
-- Target Deployment Port: adagnat                                            --
--                         Ada95 Gnat                                         --
--                                                                            --
--                   File: ada-text_io-editing.ads                            --
--                         Ada95 package: Ada.Text_IO.Editing                 --
--                                                                            --
-- Rational, the Rational logo are registered trademarks of                   --
-- Rational Software Corporation.                                             --
--                                                                            --
-- The placing of the copyright notices on Rational source code is not        --
-- intended to mean that they are published works, but are included in the    --
-- event of inadvertent publication. The source code of Rational contains     --
-- trade secrets and other valuable confidential information of Rational      --
-- Software Corporation. Rational Software Corporation and its licensors      --
-- retain ownership to Rational Products in both source and object code       --
-- format, and related documentation and all rights therein including         --
-- copyrights, patents and trade secrets.                                     --
--                                                                            --
--                                                                            --
-- U.S. Government Rights                                                     --
--                                                                            --
-- Use, duplication, or disclosure by the U.S. Government is subject to       --
-- restrictions set forth in the applicable Rational License Agreement        --
-- and in DFARS 227.7202-1(a) and 227.7202-3(a) (1995), DFARS                 --
-- 252.227-7013(c)(1)(ii)(Oct 1988), FAR 12.212(a) 1995, FAR 52.227-19,       --
-- or FAR 52.227-14, as applicable.                                           --
--                                                                            --
-- Unless otherwise agreed to in writing, use of Rational products is         --
-- governed by the Rational Product License Agreement provided with           --
-- the product.                                                               --
--------------------------------------------------------------------------------

--------------------------------------------------------------------------
-- $Revision: 1.2 $
-- $Descr: Ada95 package: Ada.Text_IO.Editing$
--------------------------------------------------------------------------
--
-- Ada95 Source Definition,
-- From LRM Ada95 F.3.3 - The Package Text_IO.Editing
-- Modified to handle Implementation Dependent Definitions
--
--------------------------------------------------------------------------
with RTRT_Imp95 ;

Package Ada.Text_IO.Editing is

          type Picture is private;


          function Valid (Pic_String      : in String;
                          Blank_When_Zero : in Boolean := False) return Boolean;

          function To_Picture (Pic_String      : in String;
                               Blank_When_Zero : in Boolean := False)
             return Picture;

          function Pic_String      (Pic : in Picture) return String;
          function Blank_When_Zero (Pic : in Picture) return Boolean;

          Max_Picture_Length  : constant 
             := RTRT_Imp95.c_Ada_Text_IO_Editing_Max_Picture_Length ;

          Picture_Error       : exception;

          Default_Currency    : constant String    := "$";
          Default_Fill        : constant Character := '*';
          Default_Separator   : constant Character := ',';
          Default_Radix_Mark  : constant Character := '.';

          generic
             type Num is delta <> digits <>;
             Default_Currency   : in String    :=  Text_IO.Editing.Default_Currency;
             Default_Fill       : in Character :=  Text_IO.Editing.Default_Fill;
             Default_Separator  : in Character :=  Text_IO.Editing.Default_Separator;
             Default_Radix_Mark : in Character :=  Text_IO.Editing.Default_Radix_Mark;
          package Decimal_Output is
             function Length (Pic      : in Picture;
                              Currency : in String := Default_Currency)
                return Natural;

             function Valid (Item     : in Num;
                             Pic      : in Picture;
                             Currency : in String := Default_Currency)
                return Boolean;

             function Image (Item       : in Num;
                             Pic        : in Picture;
                             Currency   : in String    := Default_Currency;
                             Fill       : in Character := Default_Fill;
                             Separator  : in Character := Default_Separator;
                             Radix_Mark : in Character := Default_Radix_Mark)
                return String;

             procedure Put (File       : in File_Type;
                            Item       : in Num;
                            Pic        : in Picture;
                            Currency   : in String    := Default_Currency;
                            Fill       : in Character := Default_Fill;
                            Separator  : in Character := Default_Separator;
                            Radix_Mark : in Character := Default_Radix_Mark);

             procedure Put (Item       : in Num;
                            Pic        : in Picture;
                            Currency   : in String    := Default_Currency;
                            Fill       : in Character := Default_Fill;
                            Separator  : in Character := Default_Separator;
                            Radix_Mark : in Character := Default_Radix_Mark);

             procedure Put (To         : out String;
                            Item       : in Num;
                            Pic        : in Picture;
                            Currency   : in String    := Default_Currency;
                            Fill       : in Character := Default_Fill;
                            Separator  : in Character := Default_Separator;
                            Radix_Mark : in Character := Default_Radix_Mark);
          end Decimal_Output;

private

    -- not specified by the language
    Type Picture is new RTRT_Imp95.t_Ada_Text_IO_Editing_Picture ; 

end Ada.Text_IO.Editing;
--
--------------------------------------------------------------------------
