--------------------------------------------------------------------------------
-- Copyright (c) 2001-2002 Rational Software Corporation. All rights reserved.--
--                                                                            --
--                Product: Rational(R) Test RealTime                          --
--                                                                            --
--      Product Component: All                                                --
--                                                                            --
--               Language: Ada                                                --
--                                                                            --
--        Product version: 2002.05.03                                         --
--                                                                            --
-- Target Deployment Port: adagnat                                            --
--                         Ada95 Gnat                                         --
--                                                                            --
--                   File: interfaces-c-pointers.ads                          --
--                         Ada95 package: Interfaces.C.Pointers               --
--                                                                            --
-- Rational, the Rational logo are registered trademarks of                   --
-- Rational Software Corporation.                                             --
--                                                                            --
-- The placing of the copyright notices on Rational source code is not        --
-- intended to mean that they are published works, but are included in the    --
-- event of inadvertent publication. The source code of Rational contains     --
-- trade secrets and other valuable confidential information of Rational      --
-- Software Corporation. Rational Software Corporation and its licensors      --
-- retain ownership to Rational Products in both source and object code       --
-- format, and related documentation and all rights therein including         --
-- copyrights, patents and trade secrets.                                     --
--                                                                            --
--                                                                            --
-- U.S. Government Rights                                                     --
--                                                                            --
-- Use, duplication, or disclosure by the U.S. Government is subject to       --
-- restrictions set forth in the applicable Rational License Agreement        --
-- and in DFARS 227.7202-1(a) and 227.7202-3(a) (1995), DFARS                 --
-- 252.227-7013(c)(1)(ii)(Oct 1988), FAR 12.212(a) 1995, FAR 52.227-19,       --
-- or FAR 52.227-14, as applicable.                                           --
--                                                                            --
-- Unless otherwise agreed to in writing, use of Rational products is         --
-- governed by the Rational Product License Agreement provided with           --
-- the product.                                                               --
--------------------------------------------------------------------------------

--------------------------------------------------------------------------
-- $Revision: 1.2 $
-- $Descr: Ada95 package: Interfaces.C.Pointers$
--------------------------------------------------------------------------
--
-- Ada95 Source Definition,
-- From LRM Ada95 B.3.2 - The Generic Package Interfces.C.Pointers
--
--------------------------------------------------------------------------
generic

   type Index is (<>);
   type Element is private;
   type Element_Array is array (Index range <>) of aliased Element;
   Default_Terminator : Element;

package Interfaces.C.Pointers is

   pragma Preelaborate(Pointers);

          type Pointer is access all Element;

          function Value(Ref        : in Pointer;
                         Terminator : in Element := Default_Terminator)
             return Element_Array;

          function Value(Ref    : in Pointer;
                         Length : in ptrdiff_t)
             return Element_Array;

          Pointer_Error : exception;

          -- C-style Pointer arithmetic

          function "+" (Left : in Pointer;   Right : in ptrdiff_t) return Pointer;
          function "+" (Left : in ptrdiff_t; Right : in Pointer)   return Pointer;
          function "-" (Left : in Pointer;   Right : in ptrdiff_t) return Pointer;
          function "-" (Left : in Pointer;   Right : in Pointer)   return ptrdiff_t;

          procedure Increment (Ref : in out Pointer);
          procedure Decrement (Ref : in out Pointer);

          pragma Convention (Intrinsic, "+");
          pragma Convention (Intrinsic, "-");
          pragma Convention (Intrinsic, Increment);
          pragma Convention (Intrinsic, Decrement);

          function Virtual_Length (Ref        : in Pointer;
                                   Terminator : in Element := Default_Terminator)
             return ptrdiff_t;

          procedure Copy_Terminated_Array (Source     : in Pointer;
                                           Target     : in Pointer;
                                           Limit      : in ptrdiff_t := ptrdiff_t'Last;
                                           Terminator : in Element :=  Default_Terminator);

          procedure Copy_Array (Source  : in Pointer;
                                Target  : in Pointer;
                                Length  : in ptrdiff_t);

end Interfaces.C.Pointers;
--
--------------------------------------------------------------------------
