--------------------------------------------------------------------------------
-- Copyright (c) 2001-2002 Rational Software Corporation. All rights reserved.--
--                                                                            --
--                Product: Rational(R) Test RealTime                          --
--                                                                            --
--      Product Component: All                                                --
--                                                                            --
--               Language: Ada                                                --
--                                                                            --
--        Product version: 2002.05.03                                         --
--                                                                            --
-- Target Deployment Port: adagnat                                            --
--                         Ada95 Gnat                                         --
--                                                                            --
--                   File: interfaces-c.ads                                   --
--                         Ada95 package: Interfaces.C                        --
--                                                                            --
-- Rational, the Rational logo are registered trademarks of                   --
-- Rational Software Corporation.                                             --
--                                                                            --
-- The placing of the copyright notices on Rational source code is not        --
-- intended to mean that they are published works, but are included in the    --
-- event of inadvertent publication. The source code of Rational contains     --
-- trade secrets and other valuable confidential information of Rational      --
-- Software Corporation. Rational Software Corporation and its licensors      --
-- retain ownership to Rational Products in both source and object code       --
-- format, and related documentation and all rights therein including         --
-- copyrights, patents and trade secrets.                                     --
--                                                                            --
--                                                                            --
-- U.S. Government Rights                                                     --
--                                                                            --
-- Use, duplication, or disclosure by the U.S. Government is subject to       --
-- restrictions set forth in the applicable Rational License Agreement        --
-- and in DFARS 227.7202-1(a) and 227.7202-3(a) (1995), DFARS                 --
-- 252.227-7013(c)(1)(ii)(Oct 1988), FAR 12.212(a) 1995, FAR 52.227-19,       --
-- or FAR 52.227-14, as applicable.                                           --
--                                                                            --
-- Unless otherwise agreed to in writing, use of Rational products is         --
-- governed by the Rational Product License Agreement provided with           --
-- the product.                                                               --
--------------------------------------------------------------------------------

--------------------------------------------------------------------------
-- $Revision: 1.3 $
-- $Descr: Ada95 package: Interfaces.C $
--------------------------------------------------------------------------
--
-- Ada95 Source Definition,
-- From LRM Ada95 B.3 - Interfacing With C
-- Modified to handle Implementation Dependent Definitions
--
--------------------------------------------------------------------------
with RTRT_Imp95 ;

package Interfaces.C is

          pragma Pure(C);

          -- Declarations based on C's <limits.h>

          CHAR_BIT  : constant := RTRT_Imp95.c_Interfaces_C_CHAR_BIT;  -- typically 8
          SCHAR_MIN : constant := RTRT_Imp95.c_Interfaces_C_SCHAR_MIN;  -- typically -128
          SCHAR_MAX : constant := RTRT_Imp95.c_Interfaces_C_SCHAR_MAX;  -- typically 127
          UCHAR_MAX : constant := RTRT_Imp95.c_Interfaces_C_UCHAR_MAX;  -- typically 255

          -- Signed and Unsigned Integers
          type int   is range  RTRT_Imp95.t_Interfaces_C_int 'first.. 
	                     RTRT_Imp95.t_Interfaces_C_int 'last;
          type short is range  RTRT_Imp95.t_Interfaces_C_short 'first.. 
	                     RTRT_Imp95.t_Interfaces_C_short 'last;
          type long  is range  RTRT_Imp95.t_Interfaces_C_long 'first.. 
	                     RTRT_Imp95.t_Interfaces_C_long 'last;

          type signed_char is range SCHAR_MIN .. SCHAR_MAX;
          for signed_char'Size use CHAR_BIT;

          type unsigned       is mod  
	                     RTRT_Imp95.t_Interfaces_C_unsigned 'modulus;
          type unsigned_short is mod  
	                     RTRT_Imp95.t_Interfaces_C_unsigned_short'modulus;
          type unsigned_long  is mod  
	                     RTRT_Imp95.t_Interfaces_C_unsigned_long 'modulus;

          type unsigned_char is mod (UCHAR_MAX+1);
          for unsigned_char'Size use CHAR_BIT;

          subtype plain_char is character range  
	       RTRT_Imp95.t_Interfaces_C_plain_char 'first.. 
	       RTRT_Imp95.t_Interfaces_C_plain_char 'last;

          type ptrdiff_t is range  RTRT_Imp95.t_Interfaces_C_ptrdiff_t 'first.. RTRT_Imp95.t_Interfaces_C_ptrdiff_t 'last;

          type size_t is mod RTRT_Imp95.t_Interfaces_C_size_t'modulus ;

          -- Floating Point

          type C_float     is digits RTRT_Imp95.t_Interfaces_C_C_float'digits;

          type double      is digits RTRT_Imp95.t_Interfaces_C_double'digits;

          type long_double is digits 
	                   RTRT_Imp95.t_Interfaces_C_long_double'digits;

          -- Characters and Strings

          type char is new standard.character range  
	     RTRT_Imp95.t_Interfaces_C_char 'first.. 
	     RTRT_Imp95.t_Interfaces_C_char 'last;

          nul : constant char := char'First;

          function To_C   (Item : in Character) return char;

          function To_Ada (Item : in char) return Character;

          type char_array is array (size_t range <>) of aliased char;
          pragma Pack(char_array);
          for char_array'Component_Size use CHAR_BIT;

          function Is_Nul_Terminated (Item : in char_array) return Boolean;

          function To_C   (Item       : in String;
                           Append_Nul : in Boolean := True)
             return char_array;

          function To_Ada (Item     : in char_array;
                           Trim_Nul : in Boolean := True)
             return String;

          procedure To_C (Item       : in String;
                          Target     : out char_array;
                          Count      : out size_t;
                          Append_Nul : in Boolean := True);

          procedure To_Ada (Item     : in char_array;
                            Target   : out String;
                            Count    : out Natural;
                            Trim_Nul : in Boolean := True);

          -- Wide Character and Wide String

          type wchar_t is new wide_character range  
	      RTRT_Imp95.t_Interfaces_C_wchar_t 'first.. 
	      RTRT_Imp95.t_Interfaces_C_wchar_t 'last;

          wide_nul : constant wchar_t := wchar_t'First;

          function To_C   (Item : in Wide_Character) return wchar_t;
          function To_Ada (Item : in wchar_t       ) return Wide_Character;

          type wchar_array is array (size_t range <>) of aliased wchar_t;

          pragma Pack(wchar_array);

          function Is_Nul_Terminated (Item : in wchar_array) return Boolean;

          function To_C   (Item       : in Wide_String;
                           Append_Nul : in Boolean := True)
             return wchar_array;

          function To_Ada (Item     : in wchar_array;
                           Trim_Nul : in Boolean := True)
             return Wide_String;

          procedure To_C (Item       : in  Wide_String;
                          Target     : out wchar_array;
                          Count      : out size_t;
                          Append_Nul : in  Boolean := True);

          procedure To_Ada (Item     : in  wchar_array;
                            Target   : out Wide_String;
                            Count    : out Natural;
                            Trim_Nul : in  Boolean := True);

          Terminator_Error : exception;

end Interfaces.C;
--
--------------------------------------------------------------------------
