--------------------------------------------------------------------------------
-- Copyright (c) 2001-2002 Rational Software Corporation. All rights reserved.--
--                                                                            --
--                Product: Rational(R) Test RealTime                          --
--                                                                            --
--      Product Component: All                                                --
--                                                                            --
--               Language: Ada                                                --
--                                                                            --
--        Product version: 2002.05.03                                         --
--                                                                            --
-- Target Deployment Port: adagnat                                            --
--                         Ada95 Gnat                                         --
--                                                                            --
--                   File: interfaces-cobol.ads                               --
--                         Ada95 package: Interfaces.COBOL                    --
--                                                                            --
-- Rational, the Rational logo are registered trademarks of                   --
-- Rational Software Corporation.                                             --
--                                                                            --
-- The placing of the copyright notices on Rational source code is not        --
-- intended to mean that they are published works, but are included in the    --
-- event of inadvertent publication. The source code of Rational contains     --
-- trade secrets and other valuable confidential information of Rational      --
-- Software Corporation. Rational Software Corporation and its licensors      --
-- retain ownership to Rational Products in both source and object code       --
-- format, and related documentation and all rights therein including         --
-- copyrights, patents and trade secrets.                                     --
--                                                                            --
--                                                                            --
-- U.S. Government Rights                                                     --
--                                                                            --
-- Use, duplication, or disclosure by the U.S. Government is subject to       --
-- restrictions set forth in the applicable Rational License Agreement        --
-- and in DFARS 227.7202-1(a) and 227.7202-3(a) (1995), DFARS                 --
-- 252.227-7013(c)(1)(ii)(Oct 1988), FAR 12.212(a) 1995, FAR 52.227-19,       --
-- or FAR 52.227-14, as applicable.                                           --
--                                                                            --
-- Unless otherwise agreed to in writing, use of Rational products is         --
-- governed by the Rational Product License Agreement provided with           --
-- the product.                                                               --
--------------------------------------------------------------------------------

--------------------------------------------------------------------------
-- $Revision: 1.3 $
-- $Descr: Ada95 package: Interfaces.COBOL$
--------------------------------------------------------------------------
--
-- Ada95 Source Definition,
-- From LRM Ada95 B.4 - Interfacing With COBOL
-- Modified to handle Implementation Dependent Definitions
--
--------------------------------------------------------------------------
with RTRT_Imp95 ;

package Interfaces.COBOL is

          pragma Preelaborate(COBOL);

       -- Types and operations for internal data representations

          type Floating      is digits RTRT_Imp95.t_Interfaces_COBOL_Floating'digits ;
          type Long_Floating is digits RTRT_Imp95.t_Interfaces_COBOL_Long_Floating'digits;

          type Binary      is range  RTRT_Imp95.t_Interfaces_COBOL_Binary'first.. RTRT_Imp95.t_Interfaces_COBOL_Binary'last;
          type Long_Binary is range  RTRT_Imp95.t_Interfaces_COBOL_Long_Binary 'first.. RTRT_Imp95.t_Interfaces_COBOL_Long_Binary 'last;

          Max_Digits_Binary      : 
            constant := RTRT_Imp95.c_Interfaces_COBOL_Max_Digits_Binary;
          Max_Digits_Long_Binary : 
            constant := RTRT_Imp95.c_Interfaces_COBOL_Max_Digits_Long_Binary;

          type Decimal_Element  is 
                 mod RTRT_Imp95.t_Interfaces_COBOL_Decimal_Element'modulus ;
          type Packed_Decimal is array (Positive range <>) of Decimal_Element;
          pragma Pack(Packed_Decimal);

          type COBOL_Character is new character 
                 range  RTRT_Imp95.t_Interfaces_COBOL_COBOL_Character 'first.. RTRT_Imp95.t_Interfaces_COBOL_COBOL_Character 'last;

          -- RT-RT configured Here :
          Ada_To_COBOL : array (Character) of COBOL_Character := (others=>'0');

          COBOL_To_Ada : array (COBOL_Character) of Character := (others=>'0');

          type Alphanumeric is array (Positive range <>) of COBOL_Character;
          pragma Pack(Alphanumeric);

          function To_COBOL (Item : in String) return Alphanumeric;
          function To_Ada   (Item : in Alphanumeric) return String;

          procedure To_COBOL (Item       : in String;
                              Target     : out Alphanumeric;
                              Last       : out Natural);

          procedure To_Ada (Item     : in Alphanumeric;
                            Target   : out String;
                            Last     : out Natural);

          type Numeric is array (Positive range <>) of COBOL_Character;
          pragma Pack(Numeric);

       -- Formats for COBOL data representations

          type Display_Format is private;

          Unsigned             : constant Display_Format;
          Leading_Separate     : constant Display_Format;
          Trailing_Separate    : constant Display_Format;
          Leading_Nonseparate  : constant Display_Format;
          Trailing_Nonseparate : constant Display_Format;

          type Binary_Format is private;

          High_Order_First  : constant Binary_Format;
          Low_Order_First   : constant Binary_Format;
          Native_Binary     : constant Binary_Format;

          type Packed_Format is private;

          Packed_Unsigned   : constant Packed_Format;
          Packed_Signed     : constant Packed_Format;

       -- Types for external representation of COBOL binary data

          type Byte is mod 2**COBOL_Character'Size;
          type Byte_Array is array (Positive range <>) of Byte;
          pragma Pack (Byte_Array);

          Conversion_Error : exception;

          generic
             type Num is delta <> digits <>;
          package Decimal_Conversions is

             -- Display Formats: data values are represented as Numeric

             function Valid (Item   : in Numeric;
                             Format : in Display_Format) return Boolean;

             function Length (Format : in Display_Format) return Natural;

             function To_Decimal (Item   : in Numeric;
                                  Format : in Display_Format) return Num;

             function To_Display (Item   : in Num;
                                  Format : in Display_Format) return Numeric;

             -- Packed Formats: data values are represented as Packed_Decimal

             function Valid (Item   : in Packed_Decimal;
                             Format : in Packed_Format) return Boolean;

             function Length (Format : in Packed_Format) return Natural;

             function To_Decimal (Item   : in Packed_Decimal;
                                  Format : in Packed_Format) return Num;

             function To_Packed (Item   : in Num;
                                 Format : in Packed_Format) return Packed_Decimal;

             -- Binary Formats: external data values are represented as Byte_Array

             function Valid (Item   : in Byte_Array;
                             Format : in Binary_Format) return Boolean;

             function Length (Format : in Binary_Format) return Natural;
             function To_Decimal (Item   : in Byte_Array;
                                  Format : in Binary_Format) return Num;

             function To_Binary (Item   : in Num;
                               Format : in Binary_Format) return Byte_Array;

             -- Internal Binary formats: data values are of type Binary or Long_Binary

             function To_Decimal (Item : in Binary)      return Num;
             function To_Decimal (Item : in Long_Binary) return Num;

             function To_Binary      (Item : in Num)  return Binary;
             function To_Long_Binary (Item : in Num)  return Long_Binary;

          end Decimal_Conversions;

private

   -- not specified by the language
   type Display_Format is
     new RTRT_Imp95.t_Interfaces_COBOL_Display_Format ; 

   Unsigned             : constant Display_Format
     := Packed_Format(RTRT_Imp95.c_Interfaces_COBOL_Unsigned );
   Leading_Separate     : constant Display_Format
     := Packed_Format(RTRT_Imp95.c_Interfaces_COBOL_Leading_Separate );
   Trailing_Separate    : constant Display_Format
     := Packed_Format(RTRT_Imp95.c_Interfaces_COBOL_Trailing_Separate) ;
   Leading_Nonseparate  : constant Display_Format
     := Packed_Format(RTRT_Imp95.c_Interfaces_COBOL_Leading_Nonseparate );
   Trailing_Nonseparate : constant Display_Format
     := Packed_Format(RTRT_Imp95.c_Interfaces_COBOL_Trailing_Nonseparate );

   type Binary_Format is 
     new RTRT_Imp95.t_Interfaces_COBOL_Binary_Format ; 

   High_Order_First  : constant Binary_Format
     := Packed_Format(RTRT_Imp95.c_Interfaces_COBOL_High_Order_First );
   Low_Order_First   : constant Binary_Format
     := Packed_Format(RTRT_Imp95.c_Interfaces_COBOL_Low_Order_First );
   Native_Binary     : constant Binary_Format
     := Packed_Format(RTRT_Imp95.c_Interfaces_COBOL_Native_Binary );

   type Packed_Format is 
     new RTRT_Imp95.t_Interfaces_COBOL_Packed_Format ;

   Packed_Unsigned   : constant Packed_Format
     := Packed_Format(RTRT_Imp95.c_Interfaces_COBOL_Packed_Unsigned );
   Packed_Signed     : constant Packed_Format
     := Packed_Format(RTRT_Imp95.c_Interfaces_COBOL_Packed_Signed );


end Interfaces.COBOL;
--
--------------------------------------------------------------------------
