--------------------------------------------------------------------------------
-- Copyright (c) 2001-2002 Rational Software Corporation. All rights reserved.--
--                                                                            --
--                Product: Rational(R) Test RealTime                          --
--                                                                            --
--      Product Component: All                                                --
--                                                                            --
--               Language: Ada                                                --
--                                                                            --
--        Product version: 2002.05.03                                         --
--                                                                            --
-- Target Deployment Port: adagnat                                            --
--                         Ada95 Gnat                                         --
--                                                                            --
--                   File: system-storage_elements.ads                        --
--                         Ada95 package: System.Storage_Elements             --
--                                                                            --
-- Rational, the Rational logo are registered trademarks of                   --
-- Rational Software Corporation.                                             --
--                                                                            --
-- The placing of the copyright notices on Rational source code is not        --
-- intended to mean that they are published works, but are included in the    --
-- event of inadvertent publication. The source code of Rational contains     --
-- trade secrets and other valuable confidential information of Rational      --
-- Software Corporation. Rational Software Corporation and its licensors      --
-- retain ownership to Rational Products in both source and object code       --
-- format, and related documentation and all rights therein including         --
-- copyrights, patents and trade secrets.                                     --
--                                                                            --
--                                                                            --
-- U.S. Government Rights                                                     --
--                                                                            --
-- Use, duplication, or disclosure by the U.S. Government is subject to       --
-- restrictions set forth in the applicable Rational License Agreement        --
-- and in DFARS 227.7202-1(a) and 227.7202-3(a) (1995), DFARS                 --
-- 252.227-7013(c)(1)(ii)(Oct 1988), FAR 12.212(a) 1995, FAR 52.227-19,       --
-- or FAR 52.227-14, as applicable.                                           --
--                                                                            --
-- Unless otherwise agreed to in writing, use of Rational products is         --
-- governed by the Rational Product License Agreement provided with           --
-- the product.                                                               --
--------------------------------------------------------------------------------

--------------------------------------------------------------------------
-- $Revision: 1.3 $
-- $Descr: Ada95 package: System.Storage_Elements$
--------------------------------------------------------------------------
--
-- Ada95 Source Definition,
-- From LRM Ada95 13.7.1 - The Package System.Storage_Elements
-- Modified to handle Implementation Dependent Definitions
--
--------------------------------------------------------------------------
with RTRT_Imp95 ;

package System.Storage_Elements is

          pragma Preelaborate(System.Storage_Elements);

          type Storage_Offset is 
                 range  RTRT_Imp95.t_System_Storage_Elements_Storage_Offset 'first.. RTRT_Imp95.t_System_Storage_Elements_Storage_Offset 'last;


          subtype Storage_Count is Storage_Offset range 0..Storage_Offset'Last;

          type Storage_Element is
                 mod RTRT_Imp95.t_System_Storage_Elements_Storage_Element'modulus ;

          for Storage_Element'Size use Storage_Unit;
          type Storage_Array is array
            (Storage_Offset range <>) of aliased Storage_Element;
          for Storage_Array'Component_Size use Storage_Unit;

          -- Address Arithmetic:

          function "+"(Left : Address; Right : Storage_Offset)
            return Address;
          function "+"(Left : Storage_Offset; Right : Address)
            return Address;
          function "-"(Left : Address; Right : Storage_Offset)
            return Address;
          function "-"(Left, Right : Address)
            return Storage_Offset;

          function "mod"(Left : Address; Right : Storage_Offset)
            return Storage_Offset;

          -- Conversion to/from integers:

          type Integer_Address is 
                 range  RTRT_Imp95.t_System_Storage_Elements_Integer_Address'first.. RTRT_Imp95.t_System_Storage_Elements_Integer_Address'last;

          function To_Address(Value : Integer_Address) return Address;
          function To_Integer(Value : Address) return Integer_Address;

          pragma Convention(Intrinsic, "+");
            -- ...and so on for all language-defined subprograms declared in this package.
end System.Storage_Elements;
--
--------------------------------------------------------------------------
